OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Отметки",
    "No file provided for import" : "Няма избран файл за внасяне",
    "Unsupported file type for import" : "Типът на файла за внасяне не се поддържа",
    "Details" : "Подробности",
    "Rename" : "Преименувай",
    "Move" : "Преместване",
    "Delete" : "Изтрий",
    "New" : "Нов",
    "New folder" : "Нова папка",
    "Grid view" : "Решетъчен изглед",
    "List view" : "Списъчен изглед",
    "Select all" : "Избери всички",
    "Cancel" : "Отказ",
    "All bookmarks" : "Всички отметки",
    "Recent" : "Последни",
    "Untagged" : "Без отметки",
    "Add a bookmark" : "Добави отметка",
    "Import" : "Внасяне",
    "Export" : "Изнасяне",
    "Recently added" : "Последно добавени",
    "Alphabetically" : "По азбучен ред",
    "Most visited" : "Най-посещавани",
    "Last modified" : "Променена",
    "Bookmarklet" : "Скриптова отметка",
    "Clear data" : "Изчисти данните",
    "Delete all bookmarks" : "Изтрий всички отметки",
    "Do you really want to delete all your bookmarks?" : "Наистина ли желаете всички отметки да бъдат изтрити?",
    "Title" : "Име",
    "Link" : "Връзка",
    "Tags" : "Етикети",
    "Attachments" : "Прикачени файлове",
    "Notes" : "Бележки",
    "{time} ago" : "преди {time}",
    "Owner" : "Създател",
    "Sharing" : "Споделяне",
    "Share link" : "Връзка за споделяне",
    "Copy link" : "Копирай връзката",
    "Allow editing" : "Разреши редактиране",
    "Link copied" : "Връзката е копирана",
    "Select" : "Маркирай",
    "Privacy" : "Защита на лични данни",
    "This URL is already bookmarked! Overwrite?" : "Този адрес е вече добавен към отметките! Искате ли да презапишете?",
    "Folder" : "Папка",
    "Save" : "Запиши"
},
"nplurals=2; plural=(n != 1);");
